@@ -19,11 +19,13 @@ class ProcessName(Enum):
     EPHYS_POSTPROCESSING = "Ephys postprocessing"
     IMAGE_IMPORTING = "Image importing"
     IMAGE_ATLAS_ALIGNMENT = "Image atlas alignment"
+    IMAGE_BACKGROUND_SUBTRACTION = "Image background subtraction"
+    IMAGE_CELL_SEGMENTATION = "Image cell segmentation"
     IMAGE_DESTRIPING = "Image destriping"
     IMAGE_THRESHOLDING = "Image thresholding"
+    IMAGE_TILE_ALIGNMENT = "Image tile alignment"
     IMAGE_TILE_FUSING = "Image tile fusing"
     IMAGE_TILE_PROJECTION = "Image tile projection"
-    IMAGE_TILE_STITCHING = "Image tile stitching"
     FILE_CONVERSION = "File format conversion"
     OTHER = "Other"
     SPIKE_SORTING = "Spike sorting"
@@ -39,6 +41,7 @@ class DataProcess(AindModel):
     input_location: str = Field(..., description="Path to data inputs", title="Input location")
     output_location: str = Field(..., description="Path to data outputs", title="Output location")
     code_url: str = Field(..., description="Path to code respository", title="Code URL")
+    code_version: Optional[str] = Field(None, description="Version of the code", title="Code version")
     parameters: Dict[str, Any]
     notes: Optional[str] = None
 
@@ -58,8 +61,8 @@ class Processing(AindCoreModel):
 
 
 class Stitching(DataProcess):
-    """Description of an imaging acquisition session"""
+    """Description of tile alignment coordinate transformations"""
 
-    schema_version: str = Field("0.1.0", description="schema version for stitching", title="Version", const=True)
+    schema_version: str = Field("0.1.1", description="schema version for stitching", title="Version", const=True)
 
     tiles: List[Tile] = Field(..., title="Data tiles")
